==> mono-1.1.13.8.1.tar.gz: mono-1.1.13.8.1/mcs/class/System.Configuration/System.Configuration/DpapiProtectedConfigurationProvider.cs <==
//
// System.Configuration.DpapiProtectedConfigurationProvider.cs
//
// Authors:
// 	Chris Toshok (toshok@ximian.com)
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0
using System.Xml;
using System.Collections.Specialized;

namespace System.Configuration
{
	public sealed class DpapiProtectedConfigurationProvider: ProtectedConfigurationProvider
	{
		bool useMachineProtection;

		public override XmlNode Decrypt (XmlNode encrypted_node)
		{
			throw new NotSupportedException (
@"DpapiProtectedConfigurationProvider depends on the Microsoft Data
Protection API, and is unimplemented in Mono.  For portability's sake,
it is suggested that you use the RsaProtectedConfigurationProvider.");
		}

		public override XmlNode Encrypt (XmlNode node)
		{
			throw new NotSupportedException (
@"DpapiProtectedConfigurationProvider depends on the Microsoft Data
Protection API, and is unimplemented in Mono.  For portability's sake,
it is suggested that you use the RsaProtectedConfigurationProvider.");
		}

		[MonoTODO]
		public override void Initialize (string name, NameValueCollection configurationValues)
		{
			base.Initialize (name, configurationValues);

			string flag;

			flag = configurationValues ["useMachineProtection"];
			if (flag != null && flag.ToLower() == "true")
				useMachineProtection = true;
		}

		public bool UseMachineProtection {
			get { return useMachineProtection; }
		}
	}
}
#endif

==> mono_1.2.4.orig.tar.gz: mono-1.2.4/mcs/class/System.Configuration/System.Configuration/DpapiProtectedConfigurationProvider.cs <==
//
// System.Configuration.DpapiProtectedConfigurationProvider.cs
//
// Authors:
// 	Chris Toshok (toshok@ximian.com)
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0
using System.Xml;
using System.Collections.Specialized;

namespace System.Configuration
{
	public sealed class DpapiProtectedConfigurationProvider: ProtectedConfigurationProvider
	{
		bool useMachineProtection;

		public override XmlNode Decrypt (XmlNode encrypted_node)
		{
			throw new NotSupportedException (
@"DpapiProtectedConfigurationProvider depends on the Microsoft Data
Protection API, and is unimplemented in Mono.  For portability's sake,
it is suggested that you use the RsaProtectedConfigurationProvider.");
		}

		public override XmlNode Encrypt (XmlNode node)
		{
			throw new NotSupportedException (
@"DpapiProtectedConfigurationProvider depends on the Microsoft Data
Protection API, and is unimplemented in Mono.  For portability's sake,
it is suggested that you use the RsaProtectedConfigurationProvider.");
		}

		[MonoTODO]
		public override void Initialize (string name, NameValueCollection configurationValues)
		{
			base.Initialize (name, configurationValues);

			string flag;

			flag = configurationValues ["useMachineProtection"];
			if (flag != null && flag.ToLowerInvariant () == "true")
				useMachineProtection = true;
		}

		public bool UseMachineProtection {
			get { return useMachineProtection; }
		}
	}
}
#endif
